from awsglue.dynamicframe import (
    DynamicFrame as DynamicFrame,
    DynamicFrameCollection as DynamicFrameCollection,
)
from awsglue.utils import callsite as callsite, makeOptions as makeOptions
from typing import Any

class DataSink:
    def __init__(self, j_sink: Any, sql_ctx: Any) -> None: ...
    def setFormat(self, format: Any, **options: Any) -> None: ...
    def setAccumulableSize(self, size: Any) -> None: ...
    def setCatalogInfo(
        self, catalogDatabase: Any, catalogTableName: Any, catalogId: str = ...
    ) -> None: ...
    def writeFrame(self, dynamic_frame: Any, info: str = ...): ...
    def write(self, dynamic_frame_or_dfc: Any, info: str = ...): ...
