from awsglue.transforms import GlueTransform as GlueTransform
from typing import Any

class ErrorsAsDynamicFrame(GlueTransform):
    def __call__(self, frame: Any): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...
