from typing import Any

class GlueTransform:
    @classmethod
    def apply(cls, *args: Any, **kwargs: Any): ...
    @classmethod
    def name(cls): ...
    @classmethod
    def describeArgs(cls) -> None: ...
    @classmethod
    def describeReturn(cls) -> None: ...
    @classmethod
    def describeTransform(cls) -> None: ...
    @classmethod
    def describeErrors(cls) -> None: ...
    @classmethod
    def describe(cls): ...
    def __eq__(self, other: Any) -> Any: ...
    def __hash__(self) -> Any: ...
