from awsglue.transforms import GlueTransform as GlueTransform
from typing import Any

class SelectFromCollection(GlueTransform):
    def __call__(self, dfc: Any, key: Any, transformation_ctx: str = ...): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class MapToCollection(GlueTransform):
    def __call__(self, dfc: Any, callable: Any, transformation_ctx: str = ...): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class FlatMap(GlueTransform):
    def __call__(
        self,
        dfc: Any,
        BaseTransform: Any,
        frame_name: Any,
        transformation_ctx: str = ...,
        **base_kwargs: Any
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...
