import argparse
from .job import Job as Job
from typing import Any

def makeOptions(sc: Any, py_obj: Any): ...
def callsite(): ...
def iteritems(d: Any, **kwargs: Any): ...
def iterkeys(d: Any, **kwargs: Any): ...
def itervalues(d: Any, **kwargs: Any): ...

class GlueArgumentError(Exception): ...

class GlueArgumentParser(argparse.ArgumentParser):
    def error(self, msg: Any) -> None: ...

def getResolvedOptions(args: Any, options: Any): ...
