from awsglue.utils import callsite as callsite, makeOptions as makeOptions
from typing import Any

class StreamingDataSource:
    name: Any = ...
    def __init__(self, j_source: Any, sql_ctx: Any, name: Any) -> None: ...
    def setFormat(self, format: Any, **options: Any) -> None: ...
    def getFrame(self): ...
