from typing import Any

class Job:
    @classmethod
    def continuation_options(cls): ...
    @classmethod
    def job_bookmark_options(cls): ...
    @classmethod
    def job_bookmark_range_options(cls): ...
    @classmethod
    def id_params(cls): ...
    @classmethod
    def encryption_type_options(cls): ...
    @classmethod
    def data_lineage_options(cls): ...
    def __init__(self, glue_context: Any) -> None: ...
    def init(self, job_name: Any, args: Any = ...) -> None: ...
    def isInitialized(self): ...
    def commit(self) -> None: ...
