from typing import Any

class ApplyMapping:
    @staticmethod
    def apply(frame: Any, mappings: Any): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...
